# Table of Contents

- [styles-and-patterns](<./styles-and-patterns.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Styles and Patterns](<./Styles-and-Patterns.md>)
  - [Overview](<./Styles-and-Patterns/Overview.md>)
  - [Available Templates](<./Styles-and-Patterns/Available-Templates.md>)
